import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom
} from 'd3';

const svg = select('svg'); 

const width = +svg.attr('width');
const height = +svg.attr('height');

const xValue = d => d.horsepower;
const yValue = d => d.mpg;
const circleRadius = 7;

const xAxisLabel = 'horsepower';
const yAxisLabel = 'mpg';

const title = 'horsepower Vs mpg';

const margin = {top: 60, right: 30, bottom: 60, left: 150};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

const render = data => {
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0]);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth);
  const yAxisG = g.append('g')
    .call(yAxis)
  	
  yAxisG.select('.domain')
  		.remove();
  
  yAxisG.append('text')
  	.text(yAxisLabel)
  		.attr('transform', 'rotate(-90)')
  		.attr('x', -innerHeight / 2)
  		.attr('y', -50)
  		.attr('class', 'axisLabel')
  		.attr('text-anchor', 'middle');
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight);
  const xAxisG = g.append('g')
    .call(xAxis)
      .attr('transform', `translate(0, ${innerHeight})`);
      
  xAxisG.select('.domain')
      .remove();
  
  xAxisG.append('text')
  	.text(xAxisLabel)
  		.attr('fill', 'black')
  		.attr('x', innerWidth / 2)
  		.attr('y', 50)
  		.attr('class', 'axisLabel');
  
  g.append('text')
  	.text(title)
  		.attr('y', -20)
  		.attr('class', 'title');
  	
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('cy', d => yScale(yValue(d)));
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
  	data.forEach(d => {
    	d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
  	});
  	render(data);
	});
